﻿using Furion;
using Furion.UnifyResult;
using gpt_api.Web.Core.Filters;
using gpt_api.Web.Core.Setup;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;

namespace gpt_api.Web.Core;

public class Startup : AppStartup
{
    public void ConfigureServices(IServiceCollection services)
    {
        services.AddConsoleFormatter();
        // services.AddJwt<JwtHandler>(enableGlobalAuthorize: true); ;
        services.AddJwt<JwtHandler>();
        services.AddCorsAccessor();

        services.AddControllersWithViews()
        .AddNewtonsoftJson(options =>
        {
            options.SerializerSettings.DateFormatString = "yyyy-MM-dd HH:mm:ss";
        });


        services.AddControllers()
     
            .AddInjectWithUnifyResult<RESTfulResultProvider>();

        //日志配置
        services.AddLogSetup();


        //去除入参string前后空格
        services.Configure<MvcOptions>(options =>
        {
            options.Filters.Add<TrimInputActionFilter>();
        });


        //sqlsugar数据库配置
        services.AddSqlsugarSetup(App.Configuration["ConnectionStrings:BaseNetDB"]);

        //添加事件总线
        services.AddEventBus();

    }

    public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
    {
        if (env.IsDevelopment())
        {
            app.UseDeveloperExceptionPage();
        }

        app.UseHttpsRedirection();

        app.UseRouting();

        app.UseCorsAccessor();

        app.UseAuthentication();
        app.UseAuthorization();

        app.UseInject(string.Empty);

        app.UseEndpoints(endpoints =>
        {
            endpoints.MapControllers();
        });
    }
}
